@@ -77,7 +77,7 @@ class icmp(packet_base.PacketBase):
             return cls
         return _register_icmp_type
 
-    def __init__(self, type_, code, csum, data=None):
+    def __init__(self, type_=ICMP_ECHO_REQUEST, code=0, csum=0, data=None):
         super(icmp, self).__init__()
         self.type = type_
         self.code = code
@@ -108,6 +108,9 @@ class icmp(packet_base.PacketBase):
                 hdr += self.data.serialize()
             else:
                 hdr += self.data
+        else:
+            self.data = echo()
+            hdr += self.data.serialize()
 
         if self.csum == 0:
             self.csum = packet_utils.checksum(hdr)
@@ -115,6 +118,9 @@ class icmp(packet_base.PacketBase):
 
         return hdr
 
+    def __len__(self):
+        return self._MIN_LEN + len(self.data)
+
 
 @icmp.register_icmp_type(ICMP_ECHO_REPLY, ICMP_ECHO_REQUEST)
 class echo(stringify.StringifyMixin):
@@ -141,7 +147,7 @@ class echo(stringify.StringifyMixin):
     _PACK_STR = '!HH'
     _MIN_LEN = struct.calcsize(_PACK_STR)
 
-    def __init__(self, id_, seq, data=None):
+    def __init__(self, id_=0, seq=0, data=None):
         super(echo, self).__init__()
         self.id = id_
         self.seq = seq
@@ -167,6 +173,12 @@ class echo(stringify.StringifyMixin):
 
         return hdr
 
+    def __len__(self):
+        length = self._MIN_LEN
+        if self.data is not None:
+            length += len(self.data)
+        return length
+
 
 @icmp.register_icmp_type(ICMP_DEST_UNREACH)
 class dest_unreach(stringify.StringifyMixin):
@@ -227,6 +239,12 @@ class dest_unreach(stringify.StringifyMixin):
 
         return hdr
 
+    def __len__(self):
+        length = self._MIN_LEN
+        if self.data is not None:
+            length += len(self.data)
+        return length
+
 
 @icmp.register_icmp_type(ICMP_TIME_EXCEEDED)
 class TimeExceeded(stringify.StringifyMixin):
@@ -276,3 +294,12 @@ class TimeExceeded(stringify.StringifyMixin):
             hdr += self.data
 
         return hdr
+
+    def __len__(self):
+        length = self._MIN_LEN
+        if self.data is not None:
+            length += len(self.data)
+        return length
+
+
+icmp.set_classes(icmp._ICMP_TYPES)
