@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
-# Copyright (C) 2013 Nippon Telegraph and Telephone Corporation.
-# Copyright (C) 2013 YAMAMOTO Takashi <yamamoto at valinux co jp>
+# Copyright (C) 2013,2014 Nippon Telegraph and Telephone Corporation.
+# Copyright (C) 2013,2014 YAMAMOTO Takashi <yamamoto at valinux co jp>
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,12 +21,11 @@ import unittest
 from nose.tools import eq_
 
 from ryu.ofproto import ofproto_parser
+from ryu.ofproto import ofproto_protocol
 from ryu.ofproto import ofproto_v1_0
 from ryu.ofproto import ofproto_v1_2
 from ryu.ofproto import ofproto_v1_3
-from ryu.ofproto import ofproto_v1_0_parser
-from ryu.ofproto import ofproto_v1_2_parser
-from ryu.ofproto import ofproto_v1_3_parser
+from ryu.ofproto import ofproto_v1_4
 import json
 
 
@@ -88,29 +87,39 @@ implemented = {
         ofproto_v1_3.OFPT_GET_ASYNC_REPLY: (True, False),
         ofproto_v1_3.OFPT_SET_ASYNC: (False, True),
     },
+    5: {
+        ofproto_v1_4.OFPT_HELLO: (True, False),
+        ofproto_v1_4.OFPT_FEATURES_REQUEST: (False, True),
+        ofproto_v1_4.OFPT_FEATURES_REPLY: (True, False),
+        ofproto_v1_4.OFPT_GET_CONFIG_REQUEST: (False, True),
+        ofproto_v1_4.OFPT_GET_CONFIG_REPLY: (True, False),
+        ofproto_v1_4.OFPT_SET_CONFIG: (False, True),
+        ofproto_v1_4.OFPT_PACKET_IN: (True, False),
+        ofproto_v1_4.OFPT_FLOW_REMOVED: (True, False),
+        ofproto_v1_4.OFPT_PORT_STATUS: (True, False),
+        ofproto_v1_4.OFPT_PACKET_OUT: (False, True),
+        ofproto_v1_4.OFPT_FLOW_MOD: (False, True),
+        ofproto_v1_4.OFPT_GROUP_MOD: (False, True),
+        ofproto_v1_4.OFPT_PORT_MOD: (False, True),
+        ofproto_v1_4.OFPT_METER_MOD: (False, True),
+        ofproto_v1_4.OFPT_TABLE_MOD: (False, True),
+        ofproto_v1_4.OFPT_MULTIPART_REQUEST: (False, True),
+        ofproto_v1_4.OFPT_MULTIPART_REPLY: (True, False),
+        ofproto_v1_4.OFPT_BARRIER_REQUEST: (False, True),
+        ofproto_v1_4.OFPT_ROLE_REQUEST: (False, True),
+        ofproto_v1_4.OFPT_ROLE_REPLY: (True, False),
+        ofproto_v1_4.OFPT_GET_ASYNC_REQUEST: (False, True),
+        ofproto_v1_4.OFPT_GET_ASYNC_REPLY: (True, False),
+        ofproto_v1_4.OFPT_SET_ASYNC: (False, True),
+        ofproto_v1_4.OFPT_ROLE_STATUS: (True, False),
+    },
 }
 
 
-# XXX dummy dp for testing
-class DummyDatapath(object):
-    def __init__(self, ofp, ofpp):
-        self.ofproto = ofp
-        self.ofproto_parser = ofpp
-
-
 class Test_Parser(unittest.TestCase):
     """ Test case for ryu.ofproto, especially json representation
     """
 
-    _ofp_versions = {
-        ofproto_v1_0.OFP_VERSION: (ofproto_v1_0,
-                                   ofproto_v1_0_parser),
-        ofproto_v1_2.OFP_VERSION: (ofproto_v1_2,
-                                   ofproto_v1_2_parser),
-        ofproto_v1_3.OFP_VERSION: (ofproto_v1_3,
-                                   ofproto_v1_3_parser),
-    }
-
     def __init__(self, methodName):
         print 'init', methodName
         super(Test_Parser, self).__init__(methodName)
@@ -139,7 +148,7 @@ class Test_Parser(unittest.TestCase):
             has_parser = True
             has_serializer = True
 
-        dp = DummyDatapath(*self._ofp_versions[version])
+        dp = ofproto_protocol.ProtocolDesc(version=version)
         if has_parser:
             msg = ofproto_parser.msg(dp, version, msg_type, msg_len, xid,
                                      wire_msg)
@@ -191,6 +200,7 @@ def _add_tests():
         'of10',
         'of12',
         'of13',
+        'of14',
     ]
     for ver in ofvers:
         pdir = packet_data_dir + '/' + ver
